Index: funcs/func_numeral.c
===================================================================
--- funcs/func_numeral.c	(revision 0)
+++ funcs/func_numeral.c	(revision 0)
@@ -0,0 +1,94 @@
+/*
+ * Asterisk -- An open source telephony toolkit.
+ *
+ * Oleg Topchiy <the.edge@freelancehunt.com>
+ *
+ * See http://www.asterisk.org for more information about
+ * the Asterisk project. Please do not directly contact
+ * any of the maintainers of this project for assistance;
+ * the project provides a web site, mailing lists and IRC
+ * channels for your use.
+ *
+ * This program is free software, distributed under the terms of
+ * the GNU General Public License Version 2. See the LICENSE file
+ * at the top of the source tree.
+ */
+
+#include "asterisk.h"
+
+#include <stdlib.h>
+#include <stdio.h>
+
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 38041 $")
+
+#include "asterisk/module.h"
+#include "asterisk/channel.h"
+#include "asterisk/pbx.h"
+#include "asterisk/utils.h"
+#include "asterisk/lock.h"
+#include "asterisk/file.h"
+#include "asterisk/logger.h"
+#include "asterisk/pbx.h"
+#include "asterisk/options.h"
+#include "asterisk/app.h"
+
+#define min(a,b) ((a)<(b) ? (a) : (b))
+
+static char *builtin_function_numeral(struct ast_channel *chan, char *cmd, char *data, char *buf, size_t len) 
+{
+        int argc;
+        char *argv[4];
+	char *mydata;
+	int cases[6] = {2, 0, 1, 1, 1, 2};
+	
+	mydata = ast_strdupa(data);
+	argc = ast_app_separate_args(mydata, '|', argv, 4);
+	if (argc != 4) {
+	    ast_log(LOG_WARNING, "Incorrect usage: 4 parameters expected\n");
+	    return NULL;
+	}
+	
+	int number = atoi(argv[0]);
+	int offset = ((number%100>4) && (number%100<20)) ? 2 : cases[min(number%10, 5)];
+	ast_log(LOG_DEBUG, "Numeral found: %d %s\n", number, argv[offset+1]);	
+	ast_copy_string(buf, argv[offset+1], len);
+
+	return buf;
+}
+
+static struct ast_custom_function numeral_function = {
+	.name = "NUMERAL",
+	.desc= "count is a number to find numeral for (i.e. 541)\nform1-form3 are respective forms (i.e. hrivna,hrivni,hriven)\nExample: NUMERAL(378, hrivna, hrivni, hriven) returns 'hriven'\n",
+	.synopsis = "Correct numeral selection for Russian and Ukrainian language (yabloko, yabloka, yablok)",
+	.syntax = "NUMERAL(count, form1, form2, form3)",
+	.read = builtin_function_numeral,
+};
+
+static char *tdesc = "Numeral selection function";
+
+static int unload_module(void)
+{
+        return ast_custom_function_unregister(&numeral_function);
+}
+
+static int load_module(void)
+{
+        return ast_custom_function_register(&numeral_function);
+}
+
+static char *description(void)
+{
+	return tdesc;
+}
+
+static int usecount(void)
+{
+	return 0;
+}
+
+static const char *key(void)
+{
+        return ASTERISK_GPL_KEY;
+}
+
+STD_MOD(MOD_1 | NO_USECOUNT, NULL, NULL, NULL);
